#(SORRY_ABOUT_THAT) 8502,3188,5979,10927,7716,4320,3889,5198,658,4540
#(identify) 
#(I_FWIFFO) 1863,4746,3465,2374,5528,5237,7161
#(hi_there) 
#(ARE_YOU_SURE) 1432,4316,4226,5138,5307
#(dont_kill) 
#(we_fight_1) 
#(we_fight_2) 
#(OK_WONT) 2443
#(do_cultural) 
#(WEZZY_WEZZAH) 7000,8472,7851
#(die_slugboy) 
#(begin_ritual) 
#(MUST_DO_RITUAL_AT_HOME) 6519,4557,4917,7170,3505
#(you_wont_die_yet) 
#(ETERNAL_GRATITUDE) 5588,5317
#(we_fight) 
#(pay_for_crimes) 
#(CLUTCH_MAVEN) 8022,7580,3596,2954
#(you_may_live) 
#(HONEST_AND_FRIENDLY) 6400,6950,4676
#(what_are_coordinates) 
#(COORDINATES_ARE) 7271,2443,2794,4367
#(tell_me_coordinates) 
#(FAKE_COORDINATES) 1702,4677
#(TOO_SCARY) 3985
#(youve_got_me_all_wrong) 
#(SORRY_NO_COORDS) 1893,5848,5588,1592
#(what_doing_on_pluto_1) 
#(ABOUT_20_YEARS_AGO) 8702,5849,4396,4947
#(what_doing_on_pluto_2) 
#(WHEN_URQUAN_ARRIVED) 5047,4306,6830,6429,4196,5779,3795,5678
#(where_are_urquan) 
#(URQUAN_LEFT) 4607,4947,1692,4897
#(what_about_other_races) 
#(ABOUT_OTHER_RACES) 4647,4466,5288,4206
#(what_doing_on_pluto_3) 
#(what_about_yourself) 
#(ABOUT_MYSELF) 4035,7832,3835,5538,2844,3605,6570,1762,7461,4126,2964,4967,7161,7300,5378,5037,6780,4537,5167,5648,6099,4767,5087,2754,4316
#(STATIONED_ON_EARTH_MOON) 4626,5929,3355,3234,4997,3455,4978,2283
#(what_blaze_of_glory) 
#(BLAZE_IS) 5288,2944,5698,7070,4647,5468
#(what_about_moonbase) 
#(SET_UP_BASE) 5357,2935,7130,3365,7521
#(what_about_ilwrath) 
#(ABOUT_ILWRATH) 4476,1993,5859,4756,5779,3064,3946
#(what_about_other_spathi) 
#(really_thousands) 
#(SPATHI_ARE) 6299,6930
#(what_enemy) 
#(ENEMY_IS) 8822,5388
#(when_ilwrath) 
#(THEN_ILWRATH) 6990,2534
#(why_you_here) 
#(DREW_SHORT_STRAW) 6239,4396,5498,7100,7491,4797,4436,7091
#(how_many_crew) 
#(JUST_ME) 4777,4696,3435,5718,5028,5187,3806
#(THOUSANDS) 6300,5638,5297
#(full_of_monsters) 
#(HOW_TRUE) 2433,6139,4987,5728,5538
#(join_us) 
#(WILL_JOIN) 2693,6650,3375,2884,5658,5338,4396,5398,4306
#(WONT_JOIN_1) 1643,4857,7550,7011,5477
#(give_ship_or_die) 
#(WONT_JOIN_2) 2494,5577,7261,7671,5118,2273,8973,4817
#(WONT_JOIN_3) 4887
#(GEE_THANKS) 
#(changed_mind) 
#(youre_forgiven) 
#(THANKS_FOR_FORGIVENESS) 
#(HATE_YOU_FOREVER_SPACE) 6159,2123
#(INIT_ANGRY_HELLO_SPACE) 5168
#(SUBSEQUENT_ANGRY_HELLO_SPACE) 7010,5127
#(INIT_NEUTRAL_HELLO_SPACE) 2073,4897
#(SUBSEQUENT_NEUTRAL_HELLO_SPACE) 
#(INIT_FRIENDLY_HELLO_SPACE) 
#(SUBSEQUENT_FRIENDLY_HELLO_SPACE) 6079,3073,5965
#(INIT_ALLIED_HELLO_SPACE) 4566
#(SUBSEQUENT_ALLIED_HELLO_SPACE) 4797,1913,3004,4406,5058,5508,2633,5117
#(give_info_space) 
#(HERES_SOME_INFO) 6049
#(we_sorry_space) 
#(APOLOGIZE_AT_HOMEWORLD) 4336,2684,5878,2654,6690,2443,4306
#(we_fight_again_space) 
#(OK_FIGHT_AGAIN_SPACE) 
#(bye_angry_space) 
#(GOODBYE_ANGRY_SPACE) 3235
#(look_weird) 
#(YOU_LOOK_WEIRD) 
#(no_look_really_weird) 
#(NO_YOU_LOOK_REALLY_WEIRD) 1822,832
#(come_in_peace) 
#(AGAINST_NATURE) 4900,700,3400,5849,1000
#(prepare_to_die) 
#(ALWAYS_PREPARED) 4136,2423
#(since_friendly_give_stuff) 
#(GIVE_ADVICE) 3075
#(whats_up_space_1) 
#(GENERAL_INFO_SPACE_1) 5909,3304,6860,5428,2804,2454,2774,3815,5107
#(bye_friendly_space) 
#(GOODBYE_FRIENDLY_SPACE) 
#(looking_for_a_few_good_squids) 
#(URQUAN_SLAVES) 5498
#(why_slaves) 
#(UMGAH_TRICK) 5058,6369,5167,4667,6369,2754,2814,5518,6900,5798,4847,8061,7111,5358,3595,6539,7050,7331,5077,3996,4817
#(tell_us_about_you) 
#(ABOUT_US) 3285,6719,4557,5147
#(what_you_really_want) 
#(WANT_THIS) 8902
#(how_about_alliance) 
#(SURE) 4444
#(part_in_peace) 
#(KEEP_IT_SECRET) 4016
#(heard_youre_cowards) 
#(DARN_TOOTIN) 3224
#(wanna_fight) 
#(YES_WE_DO) 
#(so_lets_fight) 
#(OK_LETS_FIGHT) 
#(so_lets_fight_already) 
#(DONT_REALLY_WANT_TO_FIGHT) 3896
#(attack_you_now) 
#(YIPES) 1763,8032,5097,5778
#(whats_up_space_2) 
#(GENERAL_INFO_SPACE_2) 3956,3064,7892,4376,2784
#(give_us_info_from_space) 
#(GET_INFO_FROM_SPATHIWA) 5348
#(give_us_resources_space) 
#(GET_RESOURCES_FROM_SPATHIWA) 4917,5958
#(what_do_for_fun) 
#(DO_THIS_FOR_FUN) 4917,5048,5527,5408
#(bye_ally_space) 
#(GOODBYE_ALLY_SPACE) 
#(OK_WE_FIGHT_AT_PLUTO) 4256,4106,4426,3384,5109,2934,4877
